@@ -2,9 +2,9 @@ if (getRversion() >= "2.15.1") {
   utils::globalVariables(c("X1", "X2", "Y1", "Y2", "midX", "midY"))
 }
 
-#' ggnet2 - Plot a network with ggplot2
+#' Network plot
 #'
-#' Function for plotting network objects using ggplot2, with additional control
+#' Function for plotting network objects using \pkg{ggplot2}, with additional control
 #' over graphical parameters that are not supported by the \code{\link{ggnet}}
 #' function. Please visit \url{http://github.com/briatte/ggnet} for the latest
 #' version of ggnet2, and \url{https://briatte.github.io/ggnet} for a vignette
@@ -184,7 +184,7 @@ if (getRversion() >= "2.15.1") {
 #' \code{\link[sna]{gplot}} in the \code{\link[sna]{sna}} package, and
 #' \code{\link[network]{plot.network}} in the \code{\link[network]{network}}
 #' package
-#' @author Moritz Marbach and Francois Briatte, with help from Heike Hoffmann,
+#' @author Moritz Marbach and Francois Briatte, with help from Heike Hofmann,
 #' Pedro Jordano and Ming-Yu Liu
 #' @details The degree centrality measures that can be produced through the
 #' \code{size} argument will take the directedness of the network into account,
@@ -199,6 +199,9 @@ if (getRversion() >= "2.15.1") {
 #' @importFrom utils installed.packages
 #' @importFrom grDevices gray.colors
 #' @examples
+#' # Small function to display plots only if it's interactive
+#' p_ <- GGally::print_if_interactive
+#'
 #' library(network)
 #'
 #' # random adjacency matrix
@@ -214,42 +217,42 @@ if (getRversion() >= "2.15.1") {
 #' n <- network::network(m, directed = FALSE)
 #' n
 #'
-#' ggnet2(n, label = TRUE)
-#' ggnet2(n, label = TRUE, shape = 15)
-#' ggnet2(n, label = TRUE, shape = 15, color = "black", label.color = "white")
+#' p_(ggnet2(n, label = TRUE))
+#' p_(ggnet2(n, label = TRUE, shape = 15))
+#' p_(ggnet2(n, label = TRUE, shape = 15, color = "black", label.color = "white"))
 #'
 #' # add vertex attribute
 #' x = network.vertex.names(n)
 #' x = ifelse(x %in% c("a", "e", "i"), "vowel", "consonant")
 #' n %v% "phono" = x
 #'
-#' ggnet2(n, color = "phono")
-#' ggnet2(n, color = "phono", palette = c("vowel" = "gold", "consonant" = "grey"))
-#' ggnet2(n, shape = "phono", color = "phono")
+#' p_(ggnet2(n, color = "phono"))
+#' p_(ggnet2(n, color = "phono", palette = c("vowel" = "gold", "consonant" = "grey")))
+#' p_(ggnet2(n, shape = "phono", color = "phono"))
 #'
 #' if (require(RColorBrewer)) {
 #'
 #'   # random groups
 #'   n %v% "group" <- sample(LETTERS[1:3], 10, replace = TRUE)
 #'
-#'   ggnet2(n, color = "group", palette = "Set2")
+#'   p_(ggnet2(n, color = "group", palette = "Set2"))
 #'
 #' }
 #'
 #' # random weights
 #' n %e% "weight" <- sample(1:3, network.edgecount(n), replace = TRUE)
-#' ggnet2(n, edge.size = "weight", edge.label = "weight")
+#' p_(ggnet2(n, edge.size = "weight", edge.label = "weight"))
 #'
 #' # edge arrows on a directed network
-#' ggnet2(network(m, directed = TRUE), arrow.gap = 0.05, arrow.size = 10)
+#' p_(ggnet2(network(m, directed = TRUE), arrow.gap = 0.05, arrow.size = 10))
 #'
 #' # Padgett's Florentine wedding data
 #' data(flo, package = "network")
 #' flo
 #'
-#' ggnet2(flo, label = TRUE)
-#' ggnet2(flo, label = TRUE, label.trim = 4, vjust = -1, size = 3, color = 1)
-#' ggnet2(flo, label = TRUE, size = 12, color = "white")
+#' p_(ggnet2(flo, label = TRUE))
+#' p_(ggnet2(flo, label = TRUE, label.trim = 4, vjust = -1, size = 3, color = 1))
+#' p_(ggnet2(flo, label = TRUE, size = 12, color = "white"))
 ggnet2 <- function(
   net,
   mode             = "fruchtermanreingold",
@@ -307,9 +310,9 @@ ggnet2 <- function(
 
   # -- conversion to network class ---------------------------------------------
 
-  if (class(net) == "igraph" && "intergraph" %in% rownames(installed.packages())) {
+  if (inherits(net, "igraph") && "intergraph" %in% rownames(installed.packages())) {
     net = intergraph::asNetwork(net)
-  } else if (class("net") == "igraph") {
+  } else if (inherits(net, "igraph")) {
     stop("install the 'intergraph' package to use igraph objects with ggnet2")
   }
 
@@ -332,7 +335,7 @@ ggnet2 <- function(
 
   set_node = function(x, value, mode = TRUE) {
 
-    if (is.null(x) || is.na(x) || is.infinite(x) || is.nan(x)) {
+    if (is.null(x) || any(is.na(x)) || any(is.infinite(x)) || any(is.nan(x))) {
       stop(paste("incorrect", value, "value"))
     } else if (is.numeric(x) && any(x < 0)) {
       stop(paste("incorrect", value, "value"))
@@ -340,9 +343,9 @@ ggnet2 <- function(
       x
     } else if (length(x) > 1) {
       stop(paste("incorrect", value, "length"))
-    } else if (x %in% v_attr) {
+    } else if (any(x %in% v_attr)) {
       get_v(net, x)
-    } else if (mode && x == "mode" & is_bip) {
+    } else if (mode && identical(x, "mode") && is_bip) {
       set_mode(net)
     } else {
       x
@@ -352,7 +355,7 @@ ggnet2 <- function(
 
   set_edge = function(x, value) {
 
-    if (is.null(x) || is.na(x) || is.infinite(x) || is.nan(x)) {
+    if (is.null(x) || any(is.na(x)) || any(is.infinite(x)) || any(is.nan(x))) {
       stop(paste("incorrect", value, "value"))
     } else if (is.numeric(x) && any(x < 0)) {
       stop(paste("incorrect", value, "value"))
@@ -360,7 +363,7 @@ ggnet2 <- function(
       x
     } else if (length(x) > 1) {
       stop(paste("incorrect", value, "length"))
-    } else if (x %in% e_attr) {
+    } else if (any(x %in% e_attr)) {
       get_e(net, x)
     } else {
       x
